@@ -12,9 +12,9 @@ from .py_spec import PythonSpec
 
 
 class Builtin(Discover):
-    def __init__(self, options):
+    def __init__(self, options) -> None:
         super().__init__(options)
-        self.python_spec = options.python if options.python else [sys.executable]
+        self.python_spec = options.python or [sys.executable]
         self.app_data = options.app_data
         self.try_first_with = options.try_first_with
 
@@ -48,7 +48,7 @@ class Builtin(Discover):
                 return result
         return None
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         spec = self.python_spec[0] if len(self.python_spec) == 1 else self.python_spec
         return f"{self.__class__.__name__} discover of python_spec={spec!r}"
 
@@ -67,9 +67,10 @@ def get_interpreter(key, try_first_with, app_data=None, env=None):
             logging.debug("accepted %s", interpreter)
             return interpreter
         proposed_paths.add(key)
+    return None
 
 
-def propose_interpreters(spec, try_first_with, app_data, env=None):
+def propose_interpreters(spec, try_first_with, app_data, env=None):  # noqa: C901, PLR0912
     # 0. try with first
     env = os.environ if env is None else env
     for py_exe in try_first_with:
@@ -98,7 +99,7 @@ def propose_interpreters(spec, try_first_with, app_data, env=None):
 
         # 3. otherwise fallback to platform default logic
         if IS_WIN:
-            from .windows import propose_interpreters
+            from .windows import propose_interpreters  # noqa: PLC0415
 
             for interpreter in propose_interpreters(spec, app_data, env):
                 yield interpreter, True
@@ -126,20 +127,16 @@ def get_paths(env):
             path = os.confstr("CS_PATH")
         except (AttributeError, ValueError):
             path = os.defpath
-    if not path:
-        paths = []
-    else:
-        paths = [p for p in path.split(os.pathsep) if os.path.exists(p)]
-    return paths
+    return [] if not path else [p for p in path.split(os.pathsep) if os.path.exists(p)]
 
 
 class LazyPathDump:
-    def __init__(self, pos, path, env):
+    def __init__(self, pos, path, env) -> None:
         self.pos = pos
         self.path = path
         self.env = env
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         content = f"discover PATH[{self.pos}]={self.path}"
         if self.env.get("_VIRTUALENV_DEBUG"):  # this is the over the board debug
             content += " with =>"
@@ -158,7 +155,7 @@ class LazyPathDump:
 def check_path(candidate, path):
     _, ext = os.path.splitext(candidate)
     if sys.platform == "win32" and ext != ".exe":
-        candidate = candidate + ".exe"
+        candidate += ".exe"
     if os.path.isfile(candidate):
         return candidate
     candidate = os.path.join(path, candidate)
@@ -175,11 +172,11 @@ def possible_specs(spec):
 
 
 class PathPythonInfo(PythonInfo):
-    """python info from path"""
+    """python info from path."""
 
 
 __all__ = [
-    "get_interpreter",
     "Builtin",
     "PathPythonInfo",
+    "get_interpreter",
 ]
