@@ -1,4 +1,5 @@
 """https://docs.python.org/3/library/zipapp.html."""
+
 from __future__ import annotations
 
 import argparse
@@ -53,17 +54,17 @@ def create_zipapp(dest, packages):
 
 def write_packages_to_zipapp(base, dist, modules, packages, zip_app):  # noqa: C901
     has = set()
-    for name, p_w_v in packages.items():
+    for name, p_w_v in packages.items():  # noqa: PLR1702
         for platform, w_v in p_w_v.items():
             for wheel_data in w_v.values():
                 wheel = wheel_data.wheel
                 with zipfile.ZipFile(str(wheel)) as wheel_zip:
                     for filename in wheel_zip.namelist():
-                        if name in ("virtualenv",):
+                        if name == "virtualenv":
                             dest = PurePosixPath(filename)
                         else:
                             dest = base / wheel.stem / filename
-                            if dest.suffix in (".so", ".pyi"):
+                            if dest.suffix in {".so", ".pyi"}:
                                 continue
                             if dest.suffix == ".py":
                                 key = filename[:-3].replace("/", ".").replace("__init__", "").rstrip(".")
@@ -159,10 +160,12 @@ class WheelDownloader:
             req = Requirement(dep)
             markers = getattr(req.marker, "_markers", ()) or ()
             if any(
-                m for m in markers if isinstance(m, tuple) and len(m) == 3 and m[0].value == "extra"  # noqa: PLR2004
+                m
+                for m in markers
+                if isinstance(m, tuple) and len(m) == 3 and m[0].value == "extra"  # noqa: PLR2004
             ):
                 continue
-            py_versions = WheelDownloader._marker_at(markers, "python_version")  # noqa: SLF001
+            py_versions = WheelDownloader._marker_at(markers, "python_version")
             if py_versions:
                 marker = Marker('python_version < "1"')
                 marker._markers = [  # noqa: SLF001
@@ -173,13 +176,13 @@ class WheelDownloader:
                     continue
                 deleted = 0
                 for ver in py_versions:
-                    deleted += WheelDownloader._del_marker_at(markers, ver - deleted)  # noqa: SLF001
+                    deleted += WheelDownloader._del_marker_at(markers, ver - deleted)
             platforms = []
-            platform_positions = WheelDownloader._marker_at(markers, "sys_platform")  # noqa: SLF001
+            platform_positions = WheelDownloader._marker_at(markers, "sys_platform")
             deleted = 0
             for pos in platform_positions:  # can only be ore meaningfully
                 platform = f"{markers[pos][1].value}{markers[pos][2].value}"
-                deleted += WheelDownloader._del_marker_at(markers, pos - deleted)  # noqa: SLF001
+                deleted += WheelDownloader._del_marker_at(markers, pos - deleted)
                 platforms.append(platform)
             if not platforms:
                 platforms.append(None)
@@ -276,7 +279,7 @@ def get_wheels_for_support_versions(folder):
 class WheelForVersion:
     def __init__(self, wheel=None, versions=None) -> None:
         self.wheel = wheel
-        self.versions = versions if versions else []
+        self.versions = versions or []
 
     def __repr__(self) -> str:
         return f"{self.__class__.__name__}({self.wheel!r}, {self.versions!r})"
