@@ -47,7 +47,7 @@ class ActivationTester:
                     raise
                 return RuntimeError(f"{self} is not available due {exception}")
             else:
-                result = out if out else err
+                result = out or err
                 self._version = result
                 return result
         return self._version
@@ -84,7 +84,7 @@ class ActivationTester:
             assert not exception.returncode, output  # noqa: PT017
             return None
 
-        out = re.sub(r"pydev debugger: process \d+ is connecting\n\n", "", raw, re.M).strip().splitlines()
+        out = re.sub(r"pydev debugger: process \d+ is connecting\n\n", "", raw, flags=re.MULTILINE).strip().splitlines()
         self.assert_output(out, raw, tmp_path)
         return env, activate_script
 
@@ -114,15 +114,18 @@ class ActivationTester:
         return [
             self.print_python_exe(),
             self.print_os_env_var("VIRTUAL_ENV"),
+            self.print_os_env_var("VIRTUAL_ENV_PROMPT"),
             self.activate_call(activate_script),
             self.print_python_exe(),
             self.print_os_env_var("VIRTUAL_ENV"),
+            self.print_os_env_var("VIRTUAL_ENV_PROMPT"),
             self.print_prompt(),
             # \\ loads documentation from the virtualenv site packages
             self.pydoc_call,
             self.deactivate,
             self.print_python_exe(),
             self.print_os_env_var("VIRTUAL_ENV"),
+            self.print_os_env_var("VIRTUAL_ENV_PROMPT"),
             "",  # just finish with an empty new line
         ]
 
@@ -130,20 +133,23 @@ class ActivationTester:
         # pre-activation
         assert out[0], raw
         assert out[1] == "None", raw
+        assert out[2] == "None", raw
         # post-activation
         expected = self._creator.exe.parent / os.path.basename(sys.executable)
-        assert self.norm_path(out[2]) == self.norm_path(expected), raw
-        assert self.norm_path(out[3]) == self.norm_path(self._creator.dest).replace("\\\\", "\\"), raw
+        assert self.norm_path(out[3]) == self.norm_path(expected), raw
+        assert self.norm_path(out[4]) == self.norm_path(self._creator.dest).replace("\\\\", "\\"), raw
+        assert out[5] == self._creator.env_name
         # Some attempts to test the prompt output print more than 1 line.
         # So we need to check if the prompt exists on any of them.
         prompt_text = f"({self._creator.env_name}) "
-        assert any(prompt_text in line for line in out[4:-3]), raw
+        assert any(prompt_text in line for line in out[6:-4]), raw
 
-        assert out[-3] == "wrote pydoc_test.html", raw
+        assert out[-4] == "wrote pydoc_test.html", raw
         content = tmp_path / "pydoc_test.html"
         assert content.exists(), raw
         # post deactivation, same as before
-        assert out[-2] == out[0], raw
+        assert out[-3] == out[0], raw
+        assert out[-2] == "None", raw
         assert out[-1] == "None", raw
 
     def quote(self, s):
@@ -176,7 +182,7 @@ class ActivationTester:
         if sys.platform != "win32":
             result = path
         else:
-            from ctypes import create_unicode_buffer, windll
+            from ctypes import create_unicode_buffer, windll  # noqa: PLC0415
 
             buffer_cont = create_unicode_buffer(256)
             get_long_path_name = windll.kernel32.GetLongPathNameW
@@ -206,7 +212,7 @@ class RaiseOnNonSourceCall(ActivationTester):
             stderr=subprocess.PIPE,
             env=env,
         )
-        out, _err = process.communicate()
+        _out, _err = process.communicate()
         err = _err.decode("utf-8")
         assert process.returncode
         assert self.non_source_fail_message in err
